@@ -39,7 +39,7 @@ static inline int pclose(FILE *stream)
 #include <unistd.h>
 #endif
 
-#include "kconfigbackend.h"
+#include "kconfigbackend_p.h"
 #include "kconfiggroup.h"
 
 #include <qcoreapplication.h>
@@ -58,16 +58,21 @@ bool KConfigPrivate::mappingsRegistered = false;
 
 Q_GLOBAL_STATIC(QStringList, s_globalFiles) // For caching purposes.
 static QBasicMutex s_globalFilesMutex;
+Q_GLOBAL_STATIC_WITH_ARGS(QString, sGlobalFileName, (QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1String("/kdeglobals")))
+
+#ifndef Q_OS_WIN
+static const Qt::CaseSensitivity sPathCaseSensitivity = Qt::CaseSensitive;
+#else
+static const Qt::CaseSensitivity sPathCaseSensitivity = Qt::CaseInsensitive;
+#endif
 
 KConfigPrivate::KConfigPrivate(KConfig::OpenFlags flags,
                                QStandardPaths::StandardLocation resourceType)
-    : openFlags(flags), resourceType(resourceType), mBackend(Q_NULLPTR),
+    : openFlags(flags), resourceType(resourceType), mBackend(nullptr),
       bDynamicBackend(true),  bDirty(false), bReadDefaults(false),
       bFileImmutable(false), bForceGlobal(false), bSuppressGlobal(false),
       configState(KConfigBase::NoAccess)
 {
-    sGlobalFileName = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1String("/kdeglobals");
-
     static QBasicAtomicInt use_etc_kderc = Q_BASIC_ATOMIC_INITIALIZER(-1);
     if (use_etc_kderc.load() < 0) {
         use_etc_kderc.store( !qEnvironmentVariableIsSet("KDE_SKIP_KDERC"));    // for unit tests
@@ -81,6 +86,7 @@ KConfigPrivate::KConfigPrivate(KConfig::OpenFlags flags,
             QStringLiteral("/etc/kde5rc");
 #endif
         if (!QFileInfo(etc_kderc).isReadable()) {
+            use_etc_kderc.store(false);
             etc_kderc.clear();
         }
     }
@@ -194,13 +200,13 @@ QString KConfigPrivate::expandString(const QString &value)
         } else if (aValue[nDollarPos + 1] != QLatin1Char('$')) {
             int nEndPos = nDollarPos + 1;
             // the next character is not $
-            QString aVarName;
+            QStringRef aVarName;
             if (aValue[nEndPos] == QLatin1Char('{')) {
                 while ((nEndPos <= aValue.length()) && (aValue[nEndPos] != QLatin1Char('}'))) {
                     nEndPos++;
                 }
                 nEndPos++;
-                aVarName = aValue.mid(nDollarPos + 2, nEndPos - nDollarPos - 3);
+                aVarName = aValue.midRef(nDollarPos + 2, nEndPos - nDollarPos - 3);
             } else {
                 while (nEndPos <= aValue.length() &&
                         (aValue[nEndPos].isNumber() ||
@@ -208,7 +214,7 @@ QString KConfigPrivate::expandString(const QString &value)
                          aValue[nEndPos] == QLatin1Char('_'))) {
                     nEndPos++;
                 }
-                aVarName = aValue.mid(nDollarPos + 1, nEndPos - nDollarPos - 1);
+                aVarName = aValue.midRef(nDollarPos + 1, nEndPos - nDollarPos - 1);
             }
             QString env;
             if (!aVarName.isEmpty()) {
@@ -227,7 +233,7 @@ QString KConfigPrivate::expandString(const QString &value)
                         } else if (aVarName == QStringLiteral("QT_CONFIG_HOME")) {
                             env = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation);
                         } else if (aVarName == QStringLiteral("QT_CACHE_HOME")) {
-			    env = QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation);
+                            env = QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation);
                         }
                     }
                 }
@@ -385,7 +391,7 @@ QMap<QString, QString> KConfig::entryMap(const QString &aGroup) const
     const QByteArray theGroup(aGroup.isEmpty() ? "<default>" : aGroup.toUtf8());
 
     const KEntryMapConstIterator theEnd = d->entryMap.constEnd();
-    KEntryMapConstIterator it = d->entryMap.findEntry(theGroup, 0, 0);
+    KEntryMapConstIterator it = d->entryMap.findEntry(theGroup, nullptr, nullptr);
     if (it != theEnd) {
         ++it; // advance past the special group entry marker
 
@@ -450,7 +456,7 @@ bool KConfig::sync()
         d->bDirty = false; // will revert to true if a config write fails
 
         if (d->wantGlobals() && writeGlobals) {
-            QExplicitlySharedDataPointer<KConfigBackend> tmp = KConfigBackend::create(d->sGlobalFileName);
+            QExplicitlySharedDataPointer<KConfigBackend> tmp = KConfigBackend::create(*sGlobalFileName);
             if (d->configState == ReadWrite && !tmp->lock()) {
                 qWarning() << "couldn't lock global file";
 
@@ -547,8 +553,6 @@ struct KConfigStaticData
 {
     QString globalMainConfigName;
     // Keep a copy so we can use it in global dtors, after qApp is gone
-    // This is a workaround for the Qt bug fixed in https://codereview.qt-project.org/107005 for Qt 5.5
-    // Revert this addition once we can depend on Qt 5.5.
     QStringList appArgs;
 };
 Q_GLOBAL_STATIC(KConfigStaticData, globalData)
@@ -592,7 +596,7 @@ void KConfigPrivate::changeFileName(const QString &name)
         } else if (wantGlobals()) { // accessing "kdeglobals" by specifying no filename and NoCascade - XXX used anywhere?
             resourceType = QStandardPaths::GenericConfigLocation;
             fileName = QStringLiteral("kdeglobals");
-            file = sGlobalFileName;
+            file = *sGlobalFileName;
         } else {
             // anonymous config
             openFlags = KConfig::SimpleConfig;
@@ -610,11 +614,7 @@ void KConfigPrivate::changeFileName(const QString &name)
 
     Q_ASSERT(!file.isEmpty());
 
-#ifndef Q_OS_WIN
-    bSuppressGlobal = (file == sGlobalFileName);
-#else
-    bSuppressGlobal = (file.compare(sGlobalFileName, Qt::CaseInsensitive) == 0);
-#endif
+    bSuppressGlobal = (file.compare(*sGlobalFileName, sPathCaseSensitivity) == 0);
 
     if (bDynamicBackend || !mBackend) { // allow dynamic changing of backend
         mBackend = KConfigBackend::create(file);
@@ -689,11 +689,8 @@ void KConfigPrivate::parseGlobalFiles()
     const QByteArray utf8Locale = locale.toUtf8();
     Q_FOREACH (const QString &file, globalFiles) {
         KConfigBackend::ParseOptions parseOpts = KConfigBackend::ParseGlobal | KConfigBackend::ParseExpansions;
-#ifndef Q_OS_WIN
-        if (file != sGlobalFileName)
-#else
-        if (file.compare(sGlobalFileName, Qt::CaseInsensitive) != 0)
-#endif
+
+        if (file.compare(*sGlobalFileName, sPathCaseSensitivity) != 0)
             parseOpts |= KConfigBackend::ParseDefaults;
 
         QExplicitlySharedDataPointer<KConfigBackend> backend = KConfigBackend::create(file);
@@ -740,11 +737,7 @@ void KConfigPrivate::parseConfigFiles()
 
         const QByteArray utf8Locale = locale.toUtf8();
         foreach (const QString &file, files) {
-#ifndef Q_OS_WIN
-            if (file == mBackend->filePath()) {
-#else
-            if (file.compare(mBackend->filePath(), Qt::CaseInsensitive) == 0) {
-#endif
+            if (file.compare(mBackend->filePath(), sPathCaseSensitivity) == 0) {
                 switch (mBackend->parseConfig(utf8Locale, entryMap, KConfigBackend::ParseExpansions)) {
                 case KConfigBackend::ParseOk:
                     break;
@@ -839,7 +832,7 @@ bool KConfig::isImmutable() const
 bool KConfig::isGroupImmutableImpl(const QByteArray &aGroup) const
 {
     Q_D(const KConfig);
-    return isImmutable() || d->entryMap.getEntryOption(aGroup, 0, 0, KEntryMap::EntryImmutable);
+    return isImmutable() || d->entryMap.getEntryOption(aGroup, nullptr, nullptr, KEntryMap::EntryImmutable);
 }
 
 #ifndef KDE_NO_DEPRECATED
@@ -870,7 +863,7 @@ const KConfigGroup KConfig::groupImpl(const QByteArray &group) const
 
 KEntryMap::EntryOptions convertToOptions(KConfig::WriteConfigFlags flags)
 {
-    KEntryMap::EntryOptions options = 0;
+    KEntryMap::EntryOptions options = nullptr;
 
     if (flags & KConfig::Persistent) {
         options |= KEntryMap::EntryDirty;
