@@ -79,17 +79,18 @@ KConfigGroup KDesktopFile::desktopGroup() const
 QString KDesktopFile::locateLocal(const QString &path)
 {
     QString relativePath;
+    QChar plus(QLatin1Char('/'));
     // Relative to config? (e.g. for autostart)
     Q_FOREACH (const QString &dir, QStandardPaths::standardLocations(QStandardPaths::GenericConfigLocation)) {
-        if (path.startsWith(dir) + '/') {
-            relativePath = dir.mid(path.length() + 1);
+        if (path.startsWith(dir + plus)) {
+            relativePath = path.mid(dir.length() + 1);
             return QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1Char('/') + relativePath;
         }
     }
     // Relative to xdg data dir? (much more common)
     Q_FOREACH (const QString &dir, QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation)) {
-        if (path.startsWith(dir) + '/') {
-            relativePath = dir.mid(path.length() + 1);
+        if (path.startsWith(dir + plus)) {
+            relativePath = path.mid(dir.length() + 1);
         }
     }
     if (relativePath.isEmpty()) {
@@ -101,8 +102,7 @@ QString KDesktopFile::locateLocal(const QString &path)
 
 bool KDesktopFile::isDesktopFile(const QString &path)
 {
-    return (path.length() > 8
-            && path.endsWith(QLatin1String(".desktop")));
+    return path.endsWith(QLatin1String(".desktop"));
 }
 
 bool KDesktopFile::isAuthorizedDesktopFile(const QString &path)
@@ -133,7 +133,7 @@ bool KDesktopFile::isAuthorizedDesktopFile(const QString &path)
             return true;
         }
     }
-    const QString servicesDir = QLatin1String("kservices5/"); // KGlobal::dirs()->xdgDataRelativePath("services")
+    const QString servicesDir = QStringLiteral("kservices5/"); // KGlobal::dirs()->xdgDataRelativePath("services")
     Q_FOREACH (const QString &xdgDataPrefix, QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation)) {
         if (QDir(xdgDataPrefix).exists()) {
             const QString prefix = QFileInfo(xdgDataPrefix).canonicalFilePath();
@@ -142,7 +142,7 @@ bool KDesktopFile::isAuthorizedDesktopFile(const QString &path)
             }
         }
     }
-    const QString autostartDir = QLatin1String("autostart/");
+    const QString autostartDir = QStringLiteral("autostart/");
     Q_FOREACH (const QString &xdgDataPrefix, QStandardPaths::standardLocations(QStandardPaths::GenericConfigLocation)) {
         if (QDir(xdgDataPrefix).exists()) {
             const QString prefix = QFileInfo(xdgDataPrefix).canonicalFilePath();
@@ -153,7 +153,7 @@ bool KDesktopFile::isAuthorizedDesktopFile(const QString &path)
     }
 
     // Forbid desktop files outside of standard locations if kiosk is set so
-    if (!KAuthorized::authorize(QLatin1String("run_desktop_files"))) {
+    if (!KAuthorized::authorize(QStringLiteral("run_desktop_files"))) {
         qWarning() << "Access to '" << path << "' denied because of 'run_desktop_files' restriction." << endl;
         return false;
     }
@@ -237,6 +237,12 @@ QStringList KDesktopFile::readActions() const
     return d->desktopGroup.readXdgListEntry("Actions");
 }
 
+QStringList KDesktopFile::readMimeTypes() const
+{
+    Q_D(const KDesktopFile);
+    return d->desktopGroup.readXdgListEntry("MimeType");
+}
+
 KConfigGroup KDesktopFile::actionGroup(const QString &group)
 {
     return KConfigGroup(this, QLatin1String("Desktop Action ") + group);
@@ -275,9 +281,12 @@ bool KDesktopFile::tryExec() const
     QString te = d->desktopGroup.readEntry("TryExec", QString());
 
     if (!te.isEmpty()) {
-        return !QStandardPaths::findExecutable(te).isEmpty();
+        if (QStandardPaths::findExecutable(te).isEmpty()) {
+            return false;
+        }
     }
     const QStringList list = d->desktopGroup.readEntry("X-KDE-AuthorizeAction", QStringList());
+
     if (!list.isEmpty()) {
         for (QStringList::ConstIterator it = list.begin();
                 it != list.end();
@@ -296,9 +305,9 @@ bool KDesktopFile::tryExec() const
             user = QString::fromLocal8Bit(qgetenv("ADMIN_ACCOUNT"));
         }
         if (user.isEmpty()) {
-            user = QString::fromLatin1("root");
+            user = QStringLiteral("root");
         }
-        if (!KAuthorized::authorize(QString::fromLatin1("user/") + user)) {
+        if (!KAuthorized::authorize(QLatin1String("user/") + user)) {
             return false;
         }
     }
@@ -317,12 +326,14 @@ bool KDesktopFile::tryExec() const
 //QString
 //KDesktopFile::resource() const { return backEnd->resource(); }
 
+#ifndef KDE_NO_DEPRECATED
 QStringList
 KDesktopFile::sortOrder() const
 {
     Q_D(const KDesktopFile);
-    return d->desktopGroup.readEntry("SortOrder", QStringList());
+    return d->desktopGroup.readXdgListEntry("SortOrder");
 }
+#endif
 
 //void KDesktopFile::virtual_hook( int id, void* data )
 //{ KConfig::virtual_hook( id, data ); }
@@ -359,12 +370,12 @@ bool KDesktopFile::noDisplay() const
         return true;
     }
     if (d->desktopGroup.hasKey("OnlyShowIn")) {
-        if (!d->desktopGroup.readXdgListEntry("OnlyShowIn").contains(QLatin1String("KDE"))) {
+        if (!d->desktopGroup.readXdgListEntry("OnlyShowIn").contains(QStringLiteral("KDE"))) {
             return true;
         }
     }
     if (d->desktopGroup.hasKey("NotShowIn")) {
-        if (d->desktopGroup.readXdgListEntry("NotShowIn").contains(QLatin1String("KDE"))) {
+        if (d->desktopGroup.readXdgListEntry("NotShowIn").contains(QStringLiteral("KDE"))) {
             return true;
         }
     }
