@@ -20,6 +20,8 @@
 #ifndef KCONFIGLOADER_H
 #define KCONFIGLOADER_H
 
+#include <QIODevice>
+
 #include <kconfiggroup.h>
 #include <kconfigskeleton.h>
 #include <ksharedconfig.h>
@@ -107,7 +109,7 @@ public:
      * @param xml the xml data; must be valid KConfigXT data
      * @param parent optional QObject parent
      **/
-    KConfigLoader(const QString &configFile, QIODevice *xml, QObject *parent = Q_NULLPTR);
+    KConfigLoader(const QString &configFile, QIODevice *xml, QObject *parent = nullptr);
 
     /**
      * Creates a KConfigSkeleton populated using the definition found in
@@ -117,7 +119,7 @@ public:
      * @param xml the xml data; must be valid KConfigXT data
      * @param parent optional QObject parent
      **/
-    KConfigLoader(KSharedConfigPtr config, QIODevice *xml, QObject *parent = Q_NULLPTR);
+    KConfigLoader(KSharedConfigPtr config, QIODevice *xml, QObject *parent = nullptr);
 
     /**
      * Creates a KConfigSkeleton populated using the definition found in
@@ -127,7 +129,7 @@ public:
      * @param xml the xml data; must be valid KConfigXT data
      * @param parent optional QObject parent
      **/
-    KConfigLoader(const KConfigGroup &config, QIODevice *xml, QObject *parent = Q_NULLPTR);
+    KConfigLoader(const KConfigGroup &config, QIODevice *xml, QObject *parent = nullptr);
 
     ~KConfigLoader();
 
@@ -167,7 +169,7 @@ protected:
     /**
      * Hack used to force writing when no default exists in config file.
      */
-    bool usrWriteConfig();
+    bool usrWriteConfig() Q_DECL_OVERRIDE;
 
 private:
     ConfigLoaderPrivate *const d;
